@@ -196,10 +196,11 @@ def _chainload(target_dir):
       sys.argv[0] = sys.executable
       for i in range(len(sys.path)):
           sys.path[i] = sys.path[i].replace(mydir,target_dir)
+      #  If we're in the bootstrap dir, try to chdir into the version dir.
+      #  This is sometimes necessary for loading of DLLs by relative path.
       curdir = getcwd()
-      newdir = curdir.replace(mydir,target_dir)
-      if newdir != curdir:
-          nt.chdir(newdir)
+      if curdir == mydir:
+          nt.chdir(target_dir)
       import zipimport
       for init_path in sys.path:
           verify(init_path)
