@@ -162,7 +162,14 @@ class DefaultVersionFinder(VersionFinder):
 
     def open_url(self,url):
         f = urllib2.urlopen(url)
-        f.size = f.headers.get("content-length",None)
+        try:
+            size = f.headers.get("content-length",None)
+            if size is not None:
+                size = int(size)
+        except ValueError:
+            pass
+        else:
+            f.size = size
         return f
 
     def find_versions(self,app):
@@ -203,13 +210,13 @@ class DefaultVersionFinder(VersionFinder):
             if path is None:
                 raise EskyVersionError(version)
             local_path = []
-            for url in path:
-                for status in self._fetch_file_iter(app,url):
-                    if status["status"] == "ready":
-                        local_path.append((status["path"],url))
-                    else:
-                        yield status
             try:
+                for url in path:
+                    for status in self._fetch_file_iter(app,url):
+                        if status["status"] == "ready":
+                            local_path.append((status["path"],url))
+                        else:
+                            yield status
                 self._prepare_version(app,version,local_path)
             except (PatchError,EskyVersionError,EnvironmentError):
                 yield {"status":"retrying","size":None}
@@ -220,6 +227,7 @@ class DefaultVersionFinder(VersionFinder):
         outfilenm = os.path.join(self._workdir(app,"downloads"),nm)
         if not os.path.exists(outfilenm):
             infile = self.open_url(urljoin(self.download_url,url))
+            outfile_size = 0
             try:
                 infile_size = infile.size
             except AttributeError:
@@ -233,14 +241,20 @@ class DefaultVersionFinder(VersionFinder):
                 partfilenm = outfilenm + ".part"
                 partfile = open(partfilenm,"wb")
                 try:
-                    data = infile.read(1024*512)
+                    data = infile.read(1024*64)
                     while data:
                         yield {"status": "downloading",
                                "size": infile_size,
                                "received": partfile.tell(),
                         }
                         partfile.write(data)
-                        data = infile.read(1024*512)
+                        outfile_size += len(data)
+                        data = infile.read(1024*64)
+                    if infile_size is not None:
+                        if outfile_size != infile_size:
+                            self.version_graph.remove_all_links(url)
+                            err = "corrupted download: %s" % (url,)
+                            raise IOError(err)
                 except Exception:
                     partfile.close()
                     os.unlink(partfilenm)
